Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(776)

Unified Diff: content/common/gpu/media/vt_video_decode_accelerator.h

Issue 1481633002: Never reuse a VideoToolbox decompression session. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2564
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/common/gpu/media/vt_video_decode_accelerator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/gpu/media/vt_video_decode_accelerator.h
diff --git a/content/common/gpu/media/vt_video_decode_accelerator.h b/content/common/gpu/media/vt_video_decode_accelerator.h
index c7289684351d47abc51caac51b6dcc15d1cc2456..6cd404d3e9402902cc4ca9443e4898cc3d334f88 100644
--- a/content/common/gpu/media/vt_video_decode_accelerator.h
+++ b/content/common/gpu/media/vt_video_decode_accelerator.h
@@ -97,7 +97,10 @@ class VTVideoDecodeAccelerator : public media::VideoDecodeAccelerator {
// Relative presentation order of this frame (see AVC spec).
int32_t pic_order_cnt;
- // Nnumber of frames after this one in decode order that can appear before
+ // Whether this frame is an IDR.
+ bool is_idr;
+
+ // Number of frames after this one in decode order that can appear before
// before it in presentation order.
int32_t reorder_window;
« no previous file with comments | « no previous file | content/common/gpu/media/vt_video_decode_accelerator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698